"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BpmnProvider = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const bpmn_service_1 = require("@sourceloop/bpmn-service");
const services_1 = require("../services");
let BpmnProvider = class BpmnProvider {
    constructor(camunda) {
        this.camunda = camunda;
    }
    value() {
        return {
            getWorkflowById: async (workflow) => {
                const response = await this.camunda.get(workflow.externalIdentifier);
                return new bpmn_service_1.Workflow({
                    provider: 'camunda',
                    id: workflow.id,
                    workflowVersion: workflow.workflowVersion,
                    externalIdentifier: response.id,
                    name: response.name,
                    inputSchema: workflow.inputSchema,
                });
            },
            startWorkflow: async (input, workflow, version) => {
                let response;
                if (version) {
                    response = await this.camunda.execute(version.externalWorkflowId, input);
                }
                else {
                    response = await this.camunda.execute(workflow.externalIdentifier, input);
                }
                return response;
            },
            createWorkflow: async (workflowDto) => {
                const response = await this.camunda.create(workflowDto.name, Buffer.from(workflowDto.bpmnFile, 'utf-8'));
                let version = 1;
                let id;
                if (response.deployedProcessDefinitions) {
                    const processDefinition = Object.values(
                    //NOSONAR
                    response.deployedProcessDefinitions)[0]; //NOSONAR
                    version = processDefinition.version;
                    id = processDefinition.id;
                }
                else {
                    throw new rest_1.HttpErrors.BadRequest('Workflow with same name and definition already exists');
                }
                return {
                    version: version,
                    provider: 'camunda',
                    processId: id,
                    externalId: id,
                    fileRef: workflowDto.bpmnFile,
                };
            },
            updateWorkflow: async (workflowDto) => {
                const response = await this.camunda.create(workflowDto.name, Buffer.from(workflowDto.bpmnFile, 'utf-8'));
                let version;
                let id;
                if (response.deployedProcessDefinitions) {
                    const processDefinition = Object.values(
                    //NOSONAR
                    response.deployedProcessDefinitions)[0]; //NOSONAR
                    version = processDefinition.version;
                    id = processDefinition.id;
                }
                else {
                    throw new Error('Workflow not changed or Worflow does not exist!');
                }
                return {
                    version: version,
                    provider: 'camunda',
                    processId: id,
                    externalId: id,
                    fileRef: workflowDto.bpmnFile,
                };
            },
            deleteWorkflowById: async (workflow) => {
                await this.camunda.delete(workflow.workflowVersions.map((version) => version.externalWorkflowId));
                return workflow;
            },
            deleteWorkflowVersionById: async (version) => {
                await this.camunda.deleteVersion(version.externalWorkflowId);
                return version;
            },
        };
    }
};
exports.BpmnProvider = BpmnProvider;
exports.BpmnProvider = BpmnProvider = tslib_1.__decorate([
    (0, core_1.bind)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, (0, core_1.service)(services_1.CamundaService)),
    tslib_1.__metadata("design:paramtypes", [services_1.CamundaService])
], BpmnProvider);
//# sourceMappingURL=bpmn.provider.js.map